Table Configuration — SQLAlchemy 1.4 Documentation

Release: 1.4.44 | Release Date: November 12, 2022

# SQLAlchemy 1.4 Documentation

# Table Configuration

This section has moved; see Declarative Table Configuration.

## Using a Hybrid Approach with __table__

This section has moved; see Declarative with Imperative Table (a.k.a. Hybrid Declarative).

## Using Reflection with Declarative

This section has moved to Mapping Declaratively with Reflected Tables.